package com.shzg.project.worn.service;

import java.util.List;
import com.shzg.project.worn.domain.WornDeclareFile;

/**
 * 申报单附件Service接口
 * 
 * @author shzg
 * @date 2026-04-14
 */
public interface IWornDeclareFileService 
{
    /**
     * 查询申报单附件
     * 
     * @param id 申报单附件主键
     * @return 申报单附件
     */
    public WornDeclareFile selectWornDeclareFileById(Long id);

    /**
     * 查询申报单附件列表
     * 
     * @param wornDeclareFile 申报单附件
     * @return 申报单附件集合
     */
    public List<WornDeclareFile> selectWornDeclareFileList(WornDeclareFile wornDeclareFile);

    /**
     * 新增申报单附件
     * 
     * @param wornDeclareFile 申报单附件
     * @return 结果
     */
    public int insertWornDeclareFile(WornDeclareFile wornDeclareFile);

    /**
     * 修改申报单附件
     * 
     * @param wornDeclareFile 申报单附件
     * @return 结果
     */
    public int updateWornDeclareFile(WornDeclareFile wornDeclareFile);

    /**
     * 批量删除申报单附件
     * 
     * @param ids 需要删除的申报单附件主键集合
     * @return 结果
     */
    public int deleteWornDeclareFileByIds(Long[] ids);

    /**
     * 删除申报单附件信息
     * 
     * @param id 申报单附件主键
     * @return 结果
     */
    public int deleteWornDeclareFileById(Long id);
}
