package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.WornDeclareFile;
import com.shzg.project.worn.service.IWornDeclareFileService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * 申报单附件Controller
 * 
 * @author shzg
 * @date 2026-04-14
 */
@RestController
@RequestMapping("/worn/declareFile")
public class WornDeclareFileController extends BaseController
{
    @Autowired
    private IWornDeclareFileService wornDeclareFileService;

    /**
     * 查询申报单附件列表
     */
    @PreAuthorize("@ss.hasPermi('worn:declareFile:list')")
    @GetMapping("/list")
    public TableDataInfo list(WornDeclareFile wornDeclareFile)
    {
        startPage();
        List<WornDeclareFile> list = wornDeclareFileService.selectWornDeclareFileList(wornDeclareFile);
        return getDataTable(list);
    }

    /**
     * 导出申报单附件列表
     */
    @PreAuthorize("@ss.hasPermi('worn:declareFile:export')")
    @Log(title = "申报单附件", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WornDeclareFile wornDeclareFile)
    {
        List<WornDeclareFile> list = wornDeclareFileService.selectWornDeclareFileList(wornDeclareFile);
        ExcelUtil<WornDeclareFile> util = new ExcelUtil<WornDeclareFile>(WornDeclareFile.class);
        util.exportExcel(response, list, "申报单附件数据");
    }

    /**
     * 获取申报单附件详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:declareFile:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wornDeclareFileService.selectWornDeclareFileById(id));
    }

    /**
     * 新增申报单附件
     */
    @PreAuthorize("@ss.hasPermi('worn:declareFile:add')")
    @Log(title = "申报单附件", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WornDeclareFile wornDeclareFile)
    {
        return toAjax(wornDeclareFileService.insertWornDeclareFile(wornDeclareFile));
    }

    /**
     * 修改申报单附件
     */
    @PreAuthorize("@ss.hasPermi('worn:declareFile:edit')")
    @Log(title = "申报单附件", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WornDeclareFile wornDeclareFile)
    {
        return toAjax(wornDeclareFileService.updateWornDeclareFile(wornDeclareFile));
    }

    /**
     * 删除申报单附件
     */
    @PreAuthorize("@ss.hasPermi('worn:declareFile:remove')")
    @Log(title = "申报单附件", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wornDeclareFileService.deleteWornDeclareFileByIds(ids));
    }
}
